<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Compartment StructType
 * Meta information extracted from the WSDL
 * - documentation: Compartment accommodation information, including type and associated compartment attributes such as number and position.
 * @subpackage Structs
 */
class Compartment extends CompartmentType
{
    /**
     * The Number
     * Meta information extracted from the WSDL
     * - documentation: The compartment number.
     * - use: optional
     * @var string
     */
    public $Number;
    /**
     * The Position
     * Meta information extracted from the WSDL
     * - documentation: The compartment position, such as Close to restaurant car.
     * - use: optional
     * @var string
     */
    public $Position;
    /**
     * Constructor method for Compartment
     * @uses Compartment::setNumber()
     * @uses Compartment::setPosition()
     * @param string $number
     * @param string $position
     */
    public function __construct($number = null, $position = null)
    {
        $this
            ->setNumber($number)
            ->setPosition($position);
    }
    /**
     * Get Number value
     * @return string|null
     */
    public function getNumber()
    {
        return $this->Number;
    }
    /**
     * Set Number value
     * @param string $number
     * @return \StructType\Compartment
     */
    public function setNumber($number = null)
    {
        // validation for constraint: string
        if (!is_null($number) && !is_string($number)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($number, true), gettype($number)), __LINE__);
        }
        $this->Number = $number;
        return $this;
    }
    /**
     * Get Position value
     * @return string|null
     */
    public function getPosition()
    {
        return $this->Position;
    }
    /**
     * Set Position value
     * @uses \EnumType\CompartmentPositionType::valueIsValid()
     * @uses \EnumType\CompartmentPositionType::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $position
     * @return \StructType\Compartment
     */
    public function setPosition($position = null)
    {
        // validation for constraint: enumeration
        if (!\EnumType\CompartmentPositionType::valueIsValid($position)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \EnumType\CompartmentPositionType', is_array($position) ? implode(', ', $position) : var_export($position, true), implode(', ', \EnumType\CompartmentPositionType::getValidValues())), __LINE__);
        }
        $this->Position = $position;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\Compartment
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
