<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Feature StructType
 * Meta information extracted from the WSDL
 * - documentation: Allows for the description of any features and/or amenities that are made available as part of this specific room and this specifiic rate plan, for example, large screen television, video/DVD player in room, room service breakfast,
 * and details about that breakfast. | May be used in conjuction with the @AccessibleCode to identify the unit of measure and measurement described in the code. | A unique identifying value assigned by the creating system. The ID attribute may be used
 * to reference a primary-key value within a database or in a particular implementation. | Describes individual security and physically challenged features that a hotel offers.
 * @subpackage Structs
 */
class Feature extends AbstractStructBase
{
    /**
     * The Charge
     * Meta information extracted from the WSDL
     * - minOccurs: 0
     * @var \StructType\Charge
     */
    public $Charge;
    /**
     * The MultimediaDescriptions
     * Meta information extracted from the WSDL
     * - documentation: Multimedia information about the feature.
     * - minOccurs: 0
     * @var mixed
     */
    public $MultimediaDescriptions;
    /**
     * The DescriptiveText
     * Meta information extracted from the WSDL
     * - documentation: Descriptive text that describes the feature. | Descriptive text that describes the restaurant. | Descriptive text that describes the transportation.
     * - base: xs:string
     * - minOccurs: 0
     * - pattern: [A-Za-z0-9]{1,500}
     * @var string
     */
    public $DescriptiveText;
    /**
     * The AccessibleCode
     * Meta information extracted from the WSDL
     * - documentation: Refer to OpenTravel Code List Disability Feature Code (PHY). For any of the codes which apply to a room count, use the GuestRoom\@Quantity. Additionally, GuestRoom\@RoomTypeName may be used to pass the specific room type or you could
     * pass "all" or "total" to indicate the AccessibleCode applies to the total hotel.
     * - use: optional
     * @var string
     */
    public $AccessibleCode;
    /**
     * The SecurityCode
     * Meta information extracted from the WSDL
     * - documentation: Refer to OpenTravel Code List Security Feature Code (SEC).
     * - use: optional
     * @var string
     */
    public $SecurityCode;
    /**
     * The ExistsCode
     * Meta information extracted from the WSDL
     * - documentation: This attribute is used to explicitly define whether an amenity or service is offered. Refer to OpenTravel Codelist Option Type Code (OTC). This is used in conjunction with AccessibleCode or SecurityCode.
     * - use: optional
     * @var string
     */
    public $ExistsCode;
    /**
     * The ProximityCode
     * Meta information extracted from the WSDL
     * - documentation: Denotes the general location of a feature. Refer to OpenTravel Codelist Proximity (PRX).
     * - use: optional
     * @var string
     */
    public $ProximityCode;
    /**
     * The Description
     * Meta information extracted from the WSDL
     * - maxOccurs: 5
     * - minOccurs: 0
     * @var mixed[]
     */
    public $Description;
    /**
     * The RoomAmenity
     * Meta information extracted from the WSDL
     * - documentation: Refer to OpenTravel Code List Room Amenity Type (RMA).
     * - use: optional
     * @var string
     */
    public $RoomAmenity;
    /**
     * The Quantity
     * Meta information extracted from the WSDL
     * - documentation: Provides the quantity of the amenity in the room. When zero, the amenity is either unavailable or not allowed.
     * - use: optional
     * @var int
     */
    public $Quantity;
    /**
     * The RoomViewCode
     * Meta information extracted from the WSDL
     * - documentation: Specifies the type of view a room has. Refer to OpenTravel Code List Room View Type (RVT).
     * - use: optional
     * @var string
     */
    public $RoomViewCode;
    /**
     * The AccessibilityCode
     * Meta information extracted from the WSDL
     * - documentation: A hotel accessibility feature. Please use a value from the OpenTravel Disability Feature Code (PHY) code list.
     * - use: optional
     * @var string
     */
    public $AccessibilityCode;
    /**
     * Constructor method for Feature
     * @uses Feature::setCharge()
     * @uses Feature::setMultimediaDescriptions()
     * @uses Feature::setDescriptiveText()
     * @uses Feature::setAccessibleCode()
     * @uses Feature::setSecurityCode()
     * @uses Feature::setExistsCode()
     * @uses Feature::setProximityCode()
     * @uses Feature::setDescription()
     * @uses Feature::setRoomAmenity()
     * @uses Feature::setQuantity()
     * @uses Feature::setRoomViewCode()
     * @uses Feature::setAccessibilityCode()
     * @param \StructType\Charge $charge
     * @param mixed $multimediaDescriptions
     * @param string $descriptiveText
     * @param string $accessibleCode
     * @param string $securityCode
     * @param string $existsCode
     * @param string $proximityCode
     * @param mixed[] $description
     * @param string $roomAmenity
     * @param int $quantity
     * @param string $roomViewCode
     * @param string $accessibilityCode
     */
    public function __construct(\StructType\Charge $charge = null, $multimediaDescriptions = null, $descriptiveText = null, $accessibleCode = null, $securityCode = null, $existsCode = null, $proximityCode = null, array $description = array(), $roomAmenity = null, $quantity = null, $roomViewCode = null, $accessibilityCode = null)
    {
        $this
            ->setCharge($charge)
            ->setMultimediaDescriptions($multimediaDescriptions)
            ->setDescriptiveText($descriptiveText)
            ->setAccessibleCode($accessibleCode)
            ->setSecurityCode($securityCode)
            ->setExistsCode($existsCode)
            ->setProximityCode($proximityCode)
            ->setDescription($description)
            ->setRoomAmenity($roomAmenity)
            ->setQuantity($quantity)
            ->setRoomViewCode($roomViewCode)
            ->setAccessibilityCode($accessibilityCode);
    }
    /**
     * Get Charge value
     * @return \StructType\Charge|null
     */
    public function getCharge()
    {
        return $this->Charge;
    }
    /**
     * Set Charge value
     * @param \StructType\Charge $charge
     * @return \StructType\Feature
     */
    public function setCharge(\StructType\Charge $charge = null)
    {
        $this->Charge = $charge;
        return $this;
    }
    /**
     * Get MultimediaDescriptions value
     * @return mixed|null
     */
    public function getMultimediaDescriptions()
    {
        return $this->MultimediaDescriptions;
    }
    /**
     * Set MultimediaDescriptions value
     * @param mixed $multimediaDescriptions
     * @return \StructType\Feature
     */
    public function setMultimediaDescriptions($multimediaDescriptions = null)
    {
        $this->MultimediaDescriptions = $multimediaDescriptions;
        return $this;
    }
    /**
     * Get DescriptiveText value
     * @return string|null
     */
    public function getDescriptiveText()
    {
        return $this->DescriptiveText;
    }
    /**
     * Set DescriptiveText value
     * @param string $descriptiveText
     * @return \StructType\Feature
     */
    public function setDescriptiveText($descriptiveText = null)
    {
        // validation for constraint: string
        if (!is_null($descriptiveText) && !is_string($descriptiveText)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($descriptiveText, true), gettype($descriptiveText)), __LINE__);
        }
        // validation for constraint: pattern([A-Za-z0-9]{1,500})
        if (!is_null($descriptiveText) && !preg_match('/[A-Za-z0-9]{1,500}/', $descriptiveText)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [A-Za-z0-9]{1,500}', var_export($descriptiveText, true)), __LINE__);
        }
        $this->DescriptiveText = $descriptiveText;
        return $this;
    }
    /**
     * Get AccessibleCode value
     * @return string|null
     */
    public function getAccessibleCode()
    {
        return $this->AccessibleCode;
    }
    /**
     * Set AccessibleCode value
     * @param string $accessibleCode
     * @return \StructType\Feature
     */
    public function setAccessibleCode($accessibleCode = null)
    {
        // validation for constraint: string
        if (!is_null($accessibleCode) && !is_string($accessibleCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($accessibleCode, true), gettype($accessibleCode)), __LINE__);
        }
        $this->AccessibleCode = $accessibleCode;
        return $this;
    }
    /**
     * Get SecurityCode value
     * @return string|null
     */
    public function getSecurityCode()
    {
        return $this->SecurityCode;
    }
    /**
     * Set SecurityCode value
     * @param string $securityCode
     * @return \StructType\Feature
     */
    public function setSecurityCode($securityCode = null)
    {
        // validation for constraint: string
        if (!is_null($securityCode) && !is_string($securityCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($securityCode, true), gettype($securityCode)), __LINE__);
        }
        $this->SecurityCode = $securityCode;
        return $this;
    }
    /**
     * Get ExistsCode value
     * @return string|null
     */
    public function getExistsCode()
    {
        return $this->ExistsCode;
    }
    /**
     * Set ExistsCode value
     * @param string $existsCode
     * @return \StructType\Feature
     */
    public function setExistsCode($existsCode = null)
    {
        // validation for constraint: string
        if (!is_null($existsCode) && !is_string($existsCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($existsCode, true), gettype($existsCode)), __LINE__);
        }
        $this->ExistsCode = $existsCode;
        return $this;
    }
    /**
     * Get ProximityCode value
     * @return string|null
     */
    public function getProximityCode()
    {
        return $this->ProximityCode;
    }
    /**
     * Set ProximityCode value
     * @param string $proximityCode
     * @return \StructType\Feature
     */
    public function setProximityCode($proximityCode = null)
    {
        // validation for constraint: string
        if (!is_null($proximityCode) && !is_string($proximityCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($proximityCode, true), gettype($proximityCode)), __LINE__);
        }
        $this->ProximityCode = $proximityCode;
        return $this;
    }
    /**
     * Get Description value
     * @return mixed[]|null
     */
    public function getDescription()
    {
        return $this->Description;
    }
    /**
     * This method is responsible for validating the values passed to the setDescription method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDescription method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateDescriptionForArrayConstraintsFromSetDescription(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $featureDescriptionItem) {
            // validation for constraint: itemType
            if (false) {
                $invalidValues[] = is_object($featureDescriptionItem) ? get_class($featureDescriptionItem) : sprintf('%s(%s)', gettype($featureDescriptionItem), var_export($featureDescriptionItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The Description property can only contain items of type anyType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set Description value
     * @throws \InvalidArgumentException
     * @param mixed[] $description
     * @return \StructType\Feature
     */
    public function setDescription(array $description = array())
    {
        // validation for constraint: array
        if ('' !== ($descriptionArrayErrorMessage = self::validateDescriptionForArrayConstraintsFromSetDescription($description))) {
            throw new \InvalidArgumentException($descriptionArrayErrorMessage, __LINE__);
        }
        // validation for constraint: maxOccurs(5)
        if (is_array($description) && count($description) > 5) {
            throw new \InvalidArgumentException(sprintf('Invalid count of %s, the number of elements contained by the property must be less than or equal to 5', count($description)), __LINE__);
        }
        $this->Description = $description;
        return $this;
    }
    /**
     * Add item to Description value
     * @throws \InvalidArgumentException
     * @param mixed $item
     * @return \StructType\Feature
     */
    public function addToDescription($item)
    {
        // validation for constraint: itemType
        if (false) {
            throw new \InvalidArgumentException(sprintf('The Description property can only contain items of type anyType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        // validation for constraint: maxOccurs(5)
        if (is_array($this->Description) && count($this->Description) >= 5) {
            throw new \InvalidArgumentException(sprintf('You can\'t add anymore element to this property that already contains %s elements, the number of elements contained by the property must be less than or equal to 5', count($this->Description)), __LINE__);
        }
        $this->Description[] = $item;
        return $this;
    }
    /**
     * Get RoomAmenity value
     * @return string|null
     */
    public function getRoomAmenity()
    {
        return $this->RoomAmenity;
    }
    /**
     * Set RoomAmenity value
     * @param string $roomAmenity
     * @return \StructType\Feature
     */
    public function setRoomAmenity($roomAmenity = null)
    {
        // validation for constraint: string
        if (!is_null($roomAmenity) && !is_string($roomAmenity)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($roomAmenity, true), gettype($roomAmenity)), __LINE__);
        }
        $this->RoomAmenity = $roomAmenity;
        return $this;
    }
    /**
     * Get Quantity value
     * @return int|null
     */
    public function getQuantity()
    {
        return $this->Quantity;
    }
    /**
     * Set Quantity value
     * @param int $quantity
     * @return \StructType\Feature
     */
    public function setQuantity($quantity = null)
    {
        // validation for constraint: int
        if (!is_null($quantity) && !(is_int($quantity) || ctype_digit($quantity))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($quantity, true), gettype($quantity)), __LINE__);
        }
        $this->Quantity = $quantity;
        return $this;
    }
    /**
     * Get RoomViewCode value
     * @return string|null
     */
    public function getRoomViewCode()
    {
        return $this->RoomViewCode;
    }
    /**
     * Set RoomViewCode value
     * @param string $roomViewCode
     * @return \StructType\Feature
     */
    public function setRoomViewCode($roomViewCode = null)
    {
        // validation for constraint: string
        if (!is_null($roomViewCode) && !is_string($roomViewCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($roomViewCode, true), gettype($roomViewCode)), __LINE__);
        }
        $this->RoomViewCode = $roomViewCode;
        return $this;
    }
    /**
     * Get AccessibilityCode value
     * @return string|null
     */
    public function getAccessibilityCode()
    {
        return $this->AccessibilityCode;
    }
    /**
     * Set AccessibilityCode value
     * @param string $accessibilityCode
     * @return \StructType\Feature
     */
    public function setAccessibilityCode($accessibilityCode = null)
    {
        // validation for constraint: string
        if (!is_null($accessibilityCode) && !is_string($accessibilityCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($accessibilityCode, true), gettype($accessibilityCode)), __LINE__);
        }
        $this->AccessibilityCode = $accessibilityCode;
        return $this;
    }
    /**
     * Method called when an object has been exported with var_export() functions
     * It allows to return an object instantiated with the values
     * @see AbstractStructBase::__set_state()
     * @uses AbstractStructBase::__set_state()
     * @param array $array the exported values
     * @return \StructType\Feature
     */
    public static function __set_state(array $array)
    {
        return parent::__set_state($array);
    }
    /**
     * Method returning the class name
     * @return string __CLASS__
     */
    public function __toString()
    {
        return __CLASS__;
    }
}
